/* Declarations for HTTP support.
   Copyright (C) 1995,96  Hrvoje Niksic
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */


#ifndef HTTP_H
#define HTTP_H

/* Header HTTP definitions */
#define CONTLEN_H "Content-length:"
#define CONTRANGE_H "Content-Range:"
#define ACCEPTRANGES_H "Accept-Ranges:"
#define CONTTYPE_H "Content-type:"
#define LOCATION_H "Location:"
#define LASTMODIFIED_H "Last-Modified:"
#define TEXTHTML_S "text/html"
#define HTTP_ACCEPT "*/*"

#define PARTIAL_CONTENTS 206

/* Retrieval buffer size */
#ifndef BUFFER_SIZE
#  define BUFFER_SIZE 8192
#endif /* BUFFER_SIZE */

/* Separator for legible numbers */
#ifndef LEGIBLE_SEPARATOR
#  define LEGIBLE_SEPARATOR ','
#endif /* LEGIBLE_SEPARATOR */

/* Typedefs: */
typedef struct {
   long len;                    /* Received length. */
   long contlen;                /* Expected length. */
   long restval;                /* The restart value. */
   int res;                     /* The result of last read. */
   char *newloc;                /* New location (redirection). */
   char *remote_time;           /* Remote time-stamp string. */
   char *error;                 /* Textual HTTP error. */
   int errcode;                 /* Error code. */
   long dltime;                 /* Time of the download. */
} http_stat_t;

/* A macro to free the elements of hstat. */
#define FREEHSTAT(x)                            \
do                                              \
{                                               \
   if (x.newloc)                                \
      free(x.newloc);                           \
   if (x.remote_time)                           \
      free(x.remote_time);                      \
   if (x.error)                                 \
      free(x.error);                            \
   x.newloc = x.remote_time = x.error = NULL;   \
} while (0)

/* Function declarations */
uerr_t fetch_next_header(int, char **);

int hskip_lws(const char *);
int hparsestatline(const char *, const char **);
long hgetlen(const char *);
long hgetrange(const char *);
char *hgettype(const char *);
char *hgetlocation(const char *);
char *hgetmodified(const char *);
int haccepts_bytes(const char *);

uerr_t gethttp(urlinfo *, http_stat_t *, int *);
uerr_t http_loop(urlinfo *, char **, int *);

char *base64_encode_line(const char *);

#endif /* HTTP_H */
