/* Declarations for utilities.
   Copyright (C) 1995,96  Hrvoje Niksic
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */


#ifndef UTILS_H
#define UTILS_H

/* The size of the initial buffer for read_whole_line. */
#define DYNAMIC_LINE_BUFFER 40
/* Separator for legible numbers */
#define LEGIBLE_SEPARATOR ','
/* Is the string a hpyhen-only? */
#define ISHYPHEN(x) (*(x) == '-' && !*((x) + 1))
/* Buffer for file-loading */
#define FILE_BUFFER_SIZE 512

/* Flags for slist.  */
enum {
   NOSORT     = 1
};

enum accd {
   ALLABS = 1
};

/* A linked list of strings. The list is ordered alphabetically. */
typedef struct _slist {
   char *string;
   struct _slist *next;
} slist;

void *nmalloc(size_t);
void *nrealloc(void *, size_t);
char *nstrdup(const char *);
void memfatal(const char *);

char *strdupdelim(const char *, const char *);
char **sepstring(const char *);
int frontcmp(const char *, const char *);
char *mycuserid(char *);
void path_simplify(char *);

int exists(const char *);
int isfile(const char *);
int mymkdir(const char *);

int acceptable(const char *);
int accdir(const char *s, enum accd);
int match_backwards(const char *, const char *);
int in_acclist(const char **, const char *, int);
char *suffix(const char *s);

char *read_whole_line(FILE *);
void load_file(FILE *, char **, long *);

void free_vec(char **);
char **merge_vecs(char **, char **);
slist *add_slist(slist *, const char *, int);
int in_slist(slist *, const char *);
void free_slist(slist *);

char *legible(long);
int numdigit(long);
void prnum(char *, int);

void reset_timer(void);
long elapsed_time(void);

#endif /* UTILS_H */
